<!-- Copyright 2024 Remy Blank <remy@c-space.org> -->
<!-- SPDX-License-Identifier: MIT -->

# t-doc

This documentation describes how to install and use t-doc.

```{toctree}
:maxdepth: 1

install
edit
development
demo/index
```
